@@ -2,7 +2,8 @@ ets <- function(y, model="ZZZ", damped=NULL,
     alpha=NULL, beta=NULL, gamma=NULL, phi=NULL, additive.only=FALSE, lambda=NULL,
     lower=c(rep(0.0001,3), 0.8), upper=c(rep(0.9999,3),0.98),
     opt.crit=c("lik","amse","mse","sigma","mae"), nmse=3, bounds=c("both","usual","admissible"),
-    ic=c("aicc","aic","bic"),restrict=TRUE, use.initial.values=FALSE, ...)
+    ic=c("aicc","aic","bic"),restrict=TRUE, allow.multiplicative.trend=FALSE, 
+    use.initial.values=FALSE, ...)
 {
   #dataname <- substitute(y)
   opt.crit <- match.arg(opt.crit)
@@ -176,7 +177,12 @@ ets <- function(y, model="ZZZ", damped=NULL,
   if(errortype=="Z")
     errortype <- c("A","M")
   if(trendtype=="Z")
-    trendtype <- c("N","A","M")
+  {
+    if(allow.multiplicative.trend)
+      trendtype <- c("N","A","M")
+    else
+      trendtype <- c("N","A")
+  }
   if(seasontype=="Z")
     seasontype <- c("N","A","M")
   if(is.null(damped))
