@@ -5,7 +5,7 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     stepwise=TRUE, trace=FALSE,
     approximation=(length(x)>100 | frequency(x)>12), xreg=NULL,
     test=c("kpss","adf","pp"), seasonal.test=c("ocsb","ch"),
-    allowdrift=TRUE,lambda=NULL,
+    allowdrift=TRUE,allowmean=TRUE,lambda=NULL,
     parallel=FALSE, num.cores=2)
 {
   # Only non-stepwise parallel implemented so far.
@@ -26,6 +26,7 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     fit$series <- series
     fit$call <- match.call()
     fit$call$x <- data.frame(x=x)
+    fit$constant <- TRUE
     return(fit)
   }
   ic <- match.arg(ic)
@@ -160,10 +161,11 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
   q <- start.q <- min(start.q,max.q)
   P <- start.P <- min(start.P,max.P)
   Q <- start.Q <- min(start.Q,max.Q)
-  if(allowdrift)
-    constant <- (d+D <= 1)
-  else
-    constant <- ((d+D) == 0)
+
+  allowdrift <- allowdrift & (d+D)==1
+  allowmean <- allowmean & (d+D)==0
+
+  constant <- allowdrift | allowmean
 
   results <- matrix(NA,nrow=100,ncol=8)
 
@@ -346,7 +348,7 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
         p <- (p+1)
       }
     }
-    if(allowdrift | (d+D)==0)
+    if(allowdrift | allowmean)
     {
       if(newmodel(p,d,q,P,D,Q,!constant,results[1:k,]))
       {
@@ -483,7 +485,7 @@ myarima <- function(x, order = c(0, 0, 0), seasonal = c(0, 0, 0), constant=TRUE,
                 minroot <- min(minroot,abs(polyroot(c(1,testvec))))
             }
         }
-        if(minroot < 1 + 1e-3)
+        if(minroot < 1 + 1e-2) # Previously 1+1e-3
             fit$ic <- Inf # Don't like this model
         if(trace)
             cat("\n",arima.string(fit),":",fit$ic)
